@@ -1,3 +1,10 @@
+/*
+ * Copyright (c) 1992-1998 Michael A. Cooper.
+ * This software may be freely used and distributed provided it is not
+ * sold for profit or used in part or in whole for commercial gain
+ * without prior written agreement, and the author is credited
+ * appropriately.
+ */
 /*
  * Copyright (c) 1983 Regents of the University of California.
  * All rights reserved.
@@ -33,12 +40,13 @@
 
 #ifndef lint
 static char RCSid[] = 
-"$Id: message.c,v 6.24 1996/07/19 17:00:35 michaelc Exp $";
+"$Id: message.c,v 6.25 1998/11/10 04:13:30 mcooper Exp $";
 
 static char sccsid[] = "@(#)common.c";
 
 static char copyright[] =
-"@(#) Copyright (c) 1983 Regents of the University of California.\n\
+"Copyright (c) 1992-1998 Michael A. Cooper.\n\
+@(#) Copyright (c) 1983 Regents of the University of California.\n\
  All rights reserved.\n";
 #endif /* !lint */
 
