@@ -1,15 +1,13 @@
 #ifndef lint
-static char *RCSid = "$Id: strcasecmp.c,v 1.4 1998/03/06 21:58:32 michaelc Exp $";
-#endif
-
-#ifndef lint
-static char sccsid[] = "@(#)strcasecmp.c 1.1 89/05/19 SMI"; /* from UCB 1.3 8/3/87 */
+static char *RCSid = "$Id: strcasecmp.c,v 1.6 1998/11/10 04:16:52 mcooper Exp $";
 #endif
 
 /*
- * Copyright (c) 1987 Regents of the University of California.
- * All rights reserved.  The Berkeley software License Agreement
- * specifies the terms and conditions for redistribution.
+ * Copyright (c) 1992-1998 Michael A. Cooper.
+ * This software may be freely used and distributed provided it is not
+ * sold for profit or used in part or in whole for commercial gain
+ * without prior written agreement, and the author is credited
+ * appropriately.
  */
 
 /*
