@@ -1,14 +1,7 @@
 #ifndef lint
-static char *RCSid = "$Header: /src/common/usc/lib/libgen/RCS/strerror.c,v 1.1 1992/03/21 02:48:11 mcooper Exp mcooper $";
+static char *RCSid = "$Id: strerror.c,v 1.2 1998/03/06 21:59:14 michaelc Exp $";
 #endif
 
-/*
- * $Log: strerror.c,v $
- * Revision 1.1  1992/03/21  02:48:11  mcooper
- * Initial revision
- *
- */
-
 #include <stdio.h>
 #include <sys/errno.h>
 
